# TODO

- [x] Fix serial name
    - currently just first 2 letters of device name as a test, since old method
      seemed so complicated
- [ ] Delete commented out and `pass` functions, was just making sure it would
  run without them
- [ ] Include example systemd service file to run at boot / keep running
- [ ] Refactor into module
- [ ] Consolidate classes?
- [ ] Make into PyPI module including console script
- [ ] Search for config in a few places
    - Should I rename to `fauxmo-config.json`?
- [ ] Needs tests
